/* Copyright (C) 2008 Igor V. Burago */

#include <cmath>
#include <limits>
#include <algorithm>
#include "Check"

using namespace Check;
using namespace std;


struct Point
{
    double x;
    double y;

    Point() : x(0.0), y(0.0) { /* nothing */ }
    Point(double a, double b) : x(a), y(b) { /* nothing */ }
};


Stream &operator >> (Stream &stream, Point &p)
{
    /* Ensure that input numbers are integer. */
    int x;
    int y;
    stream >> x >> y;

    p.x = x;
    p.y = y;
    return stream;
}


double dist(const Point &a, const Point &b)
{
    return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}


int wastageStart;
int wastagePath;
int wastageFinish;
Point start;
Point finish;


int wastage(const Point &a, const Point &b)
{
    int wS = static_cast<int>(floor(dist(start, a)) * wastageStart);
    int wP = static_cast<int>(floor(dist(a, b)) * wastagePath);
    int wF = static_cast<int>(floor(dist(finish, b)) * wastageFinish);
    return wS + wP + wF;
}


int minWastage(const Point &a, const Point &b)
{
    /* Exact accuracy specified by problem's statement. */
    const double Accuracy = 1e-3;

    int result = numeric_limits<int>::max();
    for (int offsetFrom = -1; offsetFrom <= 1; ++offsetFrom)
        for (int offsetTo = -1; offsetTo <= 1; ++offsetTo)
        {
            Point from(a.x + offsetFrom * Accuracy, a.y);
            Point to(b.x + offsetTo * Accuracy, b.y);
            result = min(result, wastage(from, to));
        }
    return result;
}


int main(int argc, char *argv[])
{
    init(argc, argv);

    input >> start >> finish;
    input >> wastageStart >> wastagePath >> wastageFinish;

    Point outputFrom;
    Point outputTo;
    Point answerFrom;
    Point answerTo;
    output >> outputFrom.x >> outputTo.x;
    answer >> answerFrom.x >> answerTo.x;

    int outputResult = minWastage(outputFrom, outputTo);
    int answerResult = minWastage(answerFrom, answerTo);
    exitUnless(
        outputResult == answerResult, outputResult < answerResult ? UnhandledError : WrongAnswer,
        "Wastage %d instead of %d", outputResult, answerResult);

    quit(SolutionAccepted);
}
