/* Copyright (C) 2008 Igor V. Burago */

#include <cstdio>
#include <cmath>
#include <cassert>
#include <limits>
#include <vector>
#include <algorithm>

using namespace std;


const int MaxCoordValue = 1000;
const int MaxWastageValue = 1000;


int startX;
int startY;
int finishX;
int finishY;
int wastageStart;
int wastagePath;
int wastageFinish;
int left;
int right;
int length;
vector<double> nodes;


inline void appendNode(const double value)
{
    if (left < value && value < right)
        nodes.push_back(value);
}


void fillCircles(const int x0, const int y0)
{
    int radius = 1;
    while (true)
    {
        int d = radius * radius - y0 * y0;
        ++radius;
        if (d < 0)
            continue;
        double x1;
        double x2;
        if (d == 0)
            appendNode(x1 = x2 = x0);
        else
        {
            double root = sqrt(static_cast<double>(d));
            appendNode(x1 = x0 - root);
            appendNode(x2 = x0 + root);
        }
        if (x1 < left && right < x2)
            break;
    }
}


int wastage(double a, double b)
{
    double sqLen = (startX - a) * (startX - a) + startY * startY;
    int wS = static_cast<int>(floor(sqrt(sqLen)) * wastageStart);
    int wP = static_cast<int>(floor(abs(a - b)) * wastagePath);
    sqLen = (finishX - b) * (finishX - b) + finishY * finishY;
    int wF = static_cast<int>(floor(sqrt(sqLen)) * wastageFinish);
    return wS + wP + wF;
}


int minWastage(double a, double b)
{
    /* Exact accuracy specified by problem's statement. */
    const double Accuracy = 1e-3;

    int result = numeric_limits<int>::max();
    for (int i = -1; i <= 1; ++i)
        for (int j = -1; j <= 1; ++j)
            if (i * j != 0)
                result = min(result, wastage(a + i * Accuracy, b + j * Accuracy));
    return result;
}


int main()
{
    freopen("input.txt", "rt", stdin);
    freopen("output.txt", "wt", stdout);

    scanf("%d%d%d%d", &startX, &startY, &finishX, &finishY);
    assert(abs(startX) <= MaxCoordValue && abs(startY) <= MaxCoordValue);
    assert(abs(finishX) <= MaxCoordValue && abs(finishY) <= MaxCoordValue);
    assert(startY < 0 && 0 < finishY);

    scanf("%d%d%d", &wastageStart, &wastagePath, &wastageFinish);
    assert(0 <= wastageStart && wastageStart <= MaxWastageValue);
    assert(0 <= wastagePath && wastagePath <= MaxWastageValue);
    assert(0 <= wastageFinish && wastageFinish <= MaxWastageValue);

    left = min(startX, finishX);
    right = max(startX, finishX);
    length = right - left + 1;
    nodes.reserve(3 * length);
    for (int pos = left; pos <= right; ++pos)
        nodes.push_back(pos);
    fillCircles(startX, startY);
    fillCircles(finishX, finishY);
    sort(nodes.begin(), nodes.end());

    int answerFirst = -1;
    int answerSecond = -1;
    int answer = numeric_limits<int>::max();
    for (size_t first = 0; first < nodes.size(); ++first)
        for (size_t second = first; second < nodes.size(); ++second)
        {
            int result = minWastage(nodes[first], nodes[second]);
            if (result < answer)
            {
                answer = result;
                answerFirst = first;
                answerSecond = second;
            }
        }

    assert(answerFirst != -1 && answerSecond != -1);
    printf("%0.6f %0.6f\n", nodes[answerFirst], nodes[answerSecond]);

    return 0;
}
